@@ -167,13 +167,13 @@ use 5.005;
 use strict;
 use Carp                   ();
 use File::Basename         ();
-use Params::Util           qw(_INSTANCE _INSTANCEDOES);
+use Params::Util 1.05      qw(_INSTANCE _INSTANCEDOES);
 use Email::MIME            ();
 use Email::MIME::Creator   ();
 use Email::Sender::Simple  ();
 use prefork 'File::Type';
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 #####################################################################
 # Constructor and Accessors
